Gleem

Package Version Hex Docs

Gleem is a DSL for the gleam programming language written in gleam.

Currently, it is not ready for use as it is still in heavy testing and development.

Install

import gleem/list

pub fn main() -> {
  install.main()
}
gleam run

Use

gleem new cool_project
import gleem/Tasks

pub fn main() -> Nil {
  tasks.define(List(tasks.Task("cool_task", "cool")))
  // The first argument on tasks.Task is the name, and the second is the file name without the ending `.gleam`.
  tasks.run()
cd project_directory
gleem run

Any further documentation can be found here

(c) 2026 Thebugcanfly13

Search Document